Header class

Constructors

Header({required String title, String? subtitle, dynamic object, VoidCallback? onTap, Color backgroundColor = Colors.white, Color color = const Color(0xFF292B2F), TextStyle textStyle = const TextStyle(color: Colors.black, fontWeight: FontWeight.w400, fontSize: 13), TextStyle subtitleStyle = const TextStyle(color: Color(0xFFA1A1A0), fontWeight: FontWeight.w300, fontSize: 10)})

Properties

backgroundColor Color
final
color Color
final
hashCode int
The hash code for this object.
no setterinherited
object → dynamic
final
onTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
subtitleStyle TextStyle
final
textStyle TextStyle
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited