Time class

Constructors

Time(int hour, int min)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hour int
final
min int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refactor(int times, int add) String
stringify(int number) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited