TimeLineStyle class
Constructors
- TimeLineStyle({Color backgroundColor = Colors.white, TextStyle textStyle = const TextStyle(color: Colors.black, fontWeight: FontWeight.w400, fontSize: 13), Color borderColor = Colors.grey})
-
const
Properties
- backgroundColor → Color
-
final
- borderColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited